@@ -1,12 +1,7 @@
-context("check captions")
-
-library(rmarkdown)
-library(xml2)
-library(officer)
 init_flextable_defaults()
 
 rmd_file_0 <- "rmd/captions.Rmd"
-if (!file.exists(rmd_file_0)) {#just for dev purpose
+if (!file.exists(rmd_file_0)) { # just for dev purpose
   rmd_file_0 <- "tests/testthat/rmd/captions.Rmd"
 }
 rmd_file <- tempfile(fileext = ".Rmd")
@@ -16,17 +11,14 @@ html_file <- gsub("\\.Rmd$", ".html", rmd_file)
 docx_file <- gsub("\\.Rmd$", ".docx", rmd_file)
 pdf_file <- gsub("\\.Rmd$", ".pdf", rmd_file)
 
-source("zzzzz.R")
-
-testthat::test_that("with html_document", {
-  skip_if_not(rmarkdown::pandoc_available())
-  skip_if_not(pandoc_version() >= numeric_version("2"))
+test_that("with html_document", {
   unlink(html_file, force = TRUE)
   render(rmd_file,
-         output_format = rmarkdown::html_document(),
-         output_file = html_file,
-         envir = new.env(),
-         quiet = TRUE)
+    output_format = rmarkdown::html_document(),
+    output_file = html_file,
+    envir = new.env(),
+    quiet = TRUE
+  )
 
   xml_doc <- get_html_xml(html_file)
 
@@ -48,20 +40,19 @@ testthat::test_that("with html_document", {
   expect_true(inherits(id_chunk, "xml_missing"))
 
   captions <- xml_find_all(xml_doc, "//table/caption/p")
-  expect_true(all(!grepl("Table [0-9]+:" , xml_text(captions))))
+  expect_true(all(!grepl("Table [0-9]+:", xml_text(captions))))
 })
 
-testthat::test_that("with html_document2", {
-  skip_if_not(rmarkdown::pandoc_available())
-  skip_if_not(pandoc_version() >= numeric_version("2"))
-  testthat::skip_if_not_installed("bookdown")
+test_that("with html_document2", {
+  skip_if_not_installed("bookdown")
 
   unlink(html_file, force = TRUE)
   render(rmd_file,
-         output_format = bookdown::html_document2(keep_md = FALSE),
-         output_file = html_file,
-         envir = new.env(),
-         quiet = TRUE)
+    output_format = bookdown::html_document2(keep_md = FALSE),
+    output_file = html_file,
+    envir = new.env(),
+    quiet = TRUE
+  )
 
   xml_doc <- get_html_xml(html_file)
 
@@ -81,25 +72,25 @@ testthat::test_that("with html_document2", {
   expect_false(inherits(id_chunk, "xml_missing"))
 
   caption <- xml_find_first(xml_doc, "//caption[span/@id='tab:id1']")
-  expect_true(grepl("Table 2:" , xml_text(caption)))
+  expect_true(grepl("Table 2:", xml_text(caption)))
 })
 
-testthat::test_that("with word_document", {
-  skip_if_not(rmarkdown::pandoc_available())
-  skip_if_not(pandoc_version() >= numeric_version("2"))
+test_that("with word_document", {
   skip_if(pandoc_version() == numeric_version("2.9.2.1"))
 
   unlink(docx_file, force = TRUE)
   render(rmd_file,
-         output_format = rmarkdown::word_document(keep_md = FALSE),
-         output_file = docx_file,
-         envir = new.env(),
-         quiet = TRUE)
+    output_format = rmarkdown::word_document(keep_md = FALSE),
+    output_file = docx_file,
+    envir = new.env(),
+    quiet = TRUE
+  )
 
   doc <- get_docx_xml(docx_file)
 
   caption_node <- xml_find_first(doc,
-                                 xpath = "/w:document/w:body/w:tbl[4]/preceding-sibling::*[1]")
+    xpath = "/w:document/w:body/w:tbl[4]/preceding-sibling::*[1]"
+  )
   expect_false(grepl("Table [1-5]+", xml_text(caption_node), fixed = TRUE))
 
   style_nodes <- xml_find_all(doc, "//w:pStyle[@w:val='TableCaption']")
@@ -114,23 +105,24 @@ testthat::test_that("with word_document", {
   expect_length(bookmarks, 0)
 })
 
-testthat::test_that("with word_document2", {
-  skip_if_not(rmarkdown::pandoc_available(version = ))
-  skip_if_not(pandoc_version() > numeric_version("2.7.3"))
-  testthat::skip_if_not_installed("bookdown")
+test_that("with word_document2", {
+  skip_if(pandoc_version() <= numeric_version("2.7.3"))
   skip_if(pandoc_version() == numeric_version("2.9.2.1"))
+  skip_if_not_installed("bookdown")
 
   unlink(docx_file, force = TRUE)
   render(rmd_file,
-         output_format = bookdown::word_document2(keep_md = FALSE),
-         output_file = docx_file,
-         envir = new.env(),
-         quiet = TRUE)
+    output_format = bookdown::word_document2(keep_md = FALSE),
+    output_file = docx_file,
+    envir = new.env(),
+    quiet = TRUE
+  )
 
   doc <- get_docx_xml(docx_file)
 
   caption_node <- xml_find_first(doc,
-                                 xpath = "/w:document/w:body/w:tbl[2]/preceding-sibling::*[1]")
+    xpath = "/w:document/w:body/w:tbl[2]/preceding-sibling::*[1]"
+  )
   expect_true(grepl("Table 2", xml_text(caption_node), fixed = TRUE))
 
   crossref_node <- xml_find_first(doc, "/w:document/w:body/w:p[2]")
@@ -147,13 +139,12 @@ testthat::test_that("with word_document2", {
   )
 
   bookmarks <- xml_find_all(doc, "//w:tbl/preceding-sibling::w:p[1]/w:bookmarkStart")
-  expect_length(bookmarks, 0)
+  expect_length(bookmarks, 3)
 })
 
 
 
-testthat::test_that("word with officer", {
-
+test_that("word with officer", {
   unlink(docx_file, force = TRUE)
   ft <- flextable(head(cars))
   ft <- theme_vanilla(ft)
@@ -167,12 +158,14 @@ testthat::test_that("word with officer", {
     autonum = run_autonum(seq_id = "tab", bkm = "id2"),
     fp_p = fp_par(
       padding = 10,
-      border = fp_border_default(color = "red", width = 1))
+      border = fp_border_default(color = "red", width = 1)
+    )
   )
   doc <- get_docx_xml(ft)
 
   caption_node <- xml_find_first(doc,
-                                 xpath = "/w:document/w:body/w:tbl/preceding-sibling::*[1]")
+    xpath = "/w:document/w:body/w:tbl/preceding-sibling::*[1]"
+  )
   expect_false(grepl("Table [1-5]+", xml_text(caption_node), fixed = TRUE))
 
   style_nodes <- xml_find_all(doc, "//w:pStyle[@w:val='TableCaption']")
@@ -185,9 +178,7 @@ testthat::test_that("word with officer", {
 
 
 test_that("with pdf_document2", {
-  skip_on_cran()
-  skip_if_not(rmarkdown::pandoc_available())
-  skip_if_not(pandoc_version() > numeric_version("2.7.3"))
+  skip_if(pandoc_version() <= numeric_version("2.7.3"))
   skip_if_not_installed("bookdown")
   skip_if_not_installed("pdftools")
 
@@ -197,7 +188,7 @@ test_that("with pdf_document2", {
     doc <- get_pdf_text(pdf_file, extract_fun = pdftools::pdf_text)
     expect_true(any(grepl("Cross-reference is there: 2", doc, fixed = TRUE)))
   } else {
-    testthat::expect_false(sucess)# only necessary to avoid a note
+    expect_false(sucess) # only necessary to avoid a note
   }
 })
 
